Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetReader ¶
func GetReader() (io.ReadCloser, error)
GetReader checks the CLI arguments provided to the program. If no argument is provided or if the first argument is "-", it returns os.Stdin. Otherwise, it attempts to open the file path provided in the first argument.
The caller is responsible for calling .Close() on the returned io.ReadCloser.
func Is_palindrome ¶ added in v0.2.0
check if a string is a palindrome
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.